#!/bin/bash


function exitwith
{
  echo ERROR: "$*"
  exit
}

function addBorders # File Top right/inner bottom left/outer UseGutters
#
#  All measurements in points
{
  IF="$1"
  T="$2"
  R="$3"
  B="$4"
  L="$5"

  WIDTHPT="$( printf '%0.0f' "$( pdftk "$IF" dump_data_utf8 output - |grep PageMediaDimensions: |head |tail -n1|cut -c 22- |sed 's/ .*//' )" )"
  HEIGHTPT="$( printf '%0.0f' "$( pdftk "$IF" dump_data_utf8 output - |grep PageMediaDimensions: |head |tail -n1|cut -c 22- |cut -f2 -d' ' )" )"
 
  NEWWIDTHPT="$(( WIDTHPT + L + R ))"
  NEWHEIGHTPT="$(( HEIGHTPT + T + B ))"
  
  [ -f "$IF" ] || exitwith "Tried to resize '$IF' which does not exist."
  
  gs -o "temp.addBorders.pdf" -sDEVICE=pdfwrite -g${NEWWIDTHPT}0x${NEWHEIGHTPT}0 \
    -c "<</PageOffset [${L} ${B}]>> setpagedevice" -f "$IF" &>/dev/null || exitwith "Could not add borders"
    
  mv "temp.addBorders.pdf" "$IF"
}

###########################################################



rm *.pdf 
libreoffice --headless --convert-to pdf *.odt

pdfjoin --quiet Digest.pdf 1-6 MattressTag.pdf 1-4 Digest.pdf 7-12 -o temp.Print.pdf

pdfbook --short-edge --quiet temp.Print.pdf -o 'Swords and Wizardry Light - Digest (Print).pdf'

pdfjoin --quiet MattressTag.pdf 5,4,3 -o temp.TabletEnd.pdf
pdfjoin --quiet --keepinfo Digest.pdf temp.TabletEnd.pdf -o temp.phoneMaster.pdf


# Crazypants, but it's quick to write this way and the page count shouldn't change.


cp temp.phoneMaster.pdf temp.phoneTrimLeft.pdf
cp temp.phoneMaster.pdf temp.phoneTrimRight.pdf
cp temp.phoneMaster.pdf temp.phoneTrimBoth.pdf
addBorders temp.phoneTrimLeft.pdf 0 0 0 -18
addBorders temp.phoneTrimRight.pdf 0 -18 0 0
addBorders temp.phoneTrimBoth.pdf 0 -9 0 -9

pdfjoin --quiet \
 --rotateoversize false \
 temp.phoneTrimBoth.pdf  1 \
 temp.phoneTrimLeft.pdf  2 \
 temp.phoneTrimRight.pdf 3 \
 temp.phoneTrimLeft.pdf  4 \
 temp.phoneTrimRight.pdf 5 \
 temp.phoneTrimLeft.pdf  6 \
 temp.phoneTrimRight.pdf 7 \
 temp.phoneTrimLeft.pdf  8 \
 temp.phoneTrimRight.pdf 9 \
 temp.phoneTrimLeft.pdf  10 \
 temp.phoneTrimRight.pdf 11 \
 temp.phoneTrimLeft.pdf  12 \
 temp.phoneTrimBoth.pdf  13 \
 temp.phoneTrimBoth.pdf  14 \
 temp.phoneTrimBoth.pdf  15 \
 --outfile 'Swords and Wizardry Light - Digest (Mobile).pdf'
 
#cp temp.phoneMaster.pdf 'Swords and Wizardry Light - Digest (Phone).pdf'


#pdfjoin --landscape Digest.pdf 1 --trim '-2.75in 0 -2.75in 0' -o temp.ScreenCover.pdf

cp ScreenCover.pdf temp.ScreenCover.pdf

pdfjoin --quiet Digest.pdf 2-12 MattressTag.pdf 4,2-3  -o temp.ScreenPages.pdf
pdfnup --quiet --keepinfo temp.ScreenPages.pdf -o temp.ScreenBlock.pdf

pdfjoin --quiet --keepinfo --rotateoversize false temp.ScreenCover.pdf temp.ScreenBlock.pdf  -o 'Swords and Wizardry Light - Digest (Screen).pdf'


# Compress

addBorders 'Swords and Wizardry Light - Digest (Print).pdf' 0 0 0 0
addBorders 'Swords and Wizardry Light - Digest (Screen).pdf' 0 0 0 0


rm temp.*.pdf MattressTag.pdf ScreenCover.pdf Digest.pdf
rm source.zip
zip source.zip README.md build.sh *.odt


